#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-client
version:              0.20.3.0
visibility:           public
id:                   servant-client-0.20.3.0-KKf4pSldYpdImxMSGmQPYw
key:                  servant-client-0.20.3.0-KKf4pSldYpdImxMSGmQPYw
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             Automatic derivation of querying functions for servant
description:
    This library lets you derive automatically Haskell functions that
    let you query each endpoint of a <http://hackage.haskell.org/package/servant servant> webservice.
    .
    See <http://docs.servant.dev/en/stable/tutorial/Client.html the client section of the tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-client/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  f7c34854db0ba7f080100865c5b0c408
exposed:              True
exposed-modules:
    Servant.Client Servant.Client.Internal.HttpClient
    Servant.Client.Internal.HttpClient.Streaming
    Servant.Client.Streaming

import-dirs:          /usr/lib/ghc-9.6.6/site-local/servant-client-0.20.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/servant-client-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/servant-client-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-client
hs-libraries:         HSservant-client-0.20.3.0-KKf4pSldYpdImxMSGmQPYw
depends:
    base-4.18.2.1 base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    exceptions-0.10.7 http-client-0.7.19-LN5QT3bQF9y5GsNu19wbhO
    http-media-0.8.1.1-5VlkQ34A66HBuiF48YbUAC
    http-types-0.12.4-57DQrkzau5HINFiGCpRQOB
    kan-extensions-5.2.8-GrYgeMUMYYkDZzGzJRXGc8
    monad-control-1.0.3.1-FisG1CqsUZHsIgnun0A0b mtl-2.3.1
    semigroupoids-6.0.2-2nn8TB8Oa649Qe5UBflX3R
    servant-0.20.3.0-9NzePVuJgxzhPEQn9hLA3
    servant-client-core-0.20.3.0-77jUP6MQjob86fKbZlAw17 stm-2.5.1.0
    time-1.12.2 transformers-0.6.1.0
    transformers-base-0.4.6.1-5X9ydruHvIG7OiSC36usmu

haddock-interfaces:
    /usr/share/doc/haskell-servant-client/html/servant-client.haddock

haddock-html:         /usr/share/doc/haskell-servant-client/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

